pub struct GraphNode {
pub node_type: GraphNodeType,
pub id: usize,
pub layer: usize,
pub position: usize,
pub token_embedding: Option<TokenEmbeddingNode>,
pub hidden_state: Option<HiddenStateNode>,
pub attention_output: Option<AttentionOutputNode>,
pub ffn_output: Option<FFNOutputNode>,
}Expand description
Graph node wrapper
Fields
node_type: GraphNodeTypeNode type
id: usizeUnique node ID
layer: usizeLayer number (for layer-specific nodes)
position: usizePosition in sequence
token_embedding: Option<TokenEmbeddingNode>Optional token embedding data
Optional hidden state data
attention_output: Option<AttentionOutputNode>Optional attention output data
ffn_output: Option<FFNOutputNode>Optional FFN output data
Implementations
Sourceimpl GraphNode
impl GraphNode
Sourcepub fn token_embedding(
id: usize,
token_id: usize,
position: usize,
embedding: DenseTensor,
) -> Self
pub fn token_embedding( id: usize, token_id: usize, position: usize, embedding: DenseTensor, ) -> Self
Create a token embedding node
Create a hidden state node
Sourcepub fn attention_output(
id: usize,
layer: usize,
head: usize,
query_pos: usize,
attended_positions: Vec<usize>,
weights: Vec<f64>,
output: DenseTensor,
) -> Self
pub fn attention_output( id: usize, layer: usize, head: usize, query_pos: usize, attended_positions: Vec<usize>, weights: Vec<f64>, output: DenseTensor, ) -> Self
Create an attention output node
Sourcepub fn ffn_output(
id: usize,
layer: usize,
position: usize,
output: DenseTensor,
) -> Self
pub fn ffn_output( id: usize, layer: usize, position: usize, output: DenseTensor, ) -> Self
Create a FFN output node
Sourcepub fn get_embedding(&self) -> Option<&TokenEmbeddingNode>
pub fn get_embedding(&self) -> Option<&TokenEmbeddingNode>
Get the embedding if this is a token embedding node
Get the hidden state if this is a hidden state node
Sourcepub fn get_attention_output(&self) -> Option<&AttentionOutputNode>
pub fn get_attention_output(&self) -> Option<&AttentionOutputNode>
Get the attention output if this is an attention output node
Sourcepub fn get_ffn_output(&self) -> Option<&FFNOutputNode>
pub fn get_ffn_output(&self) -> Option<&FFNOutputNode>
Get the FFN output if this is a FFN output node